<?php

    /**
     * For full documentation, please visit: http://docs.reduxframework.com/
     * For a more extensive sample-config file, you may look at:
     * https://github.com/reduxframework/redux-framework/blob/master/sample/sample-config.php
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "continal_option";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        'opt_name' => 'continal_option',
        'use_cdn' => TRUE,
        'display_name'     => $theme->get('Name'),
        'display_version'  => $theme->get('Version'),
        'page_title' => 'Continal Options',
        'update_notice' => FALSE,
        'admin_bar' => TRUE,
        'menu_type' => 'menu',
        'menu_title' => 'Continal Options',
        'allow_sub_menu' => TRUE,
        'page_parent_post_type' => 'your_post_type',
        'customizer' => FALSE,
        'dev_mode'   => false,
        'default_mark' => '*',
        'hints' => array(
            'icon_position' => 'right',
            'icon_color' => 'lightgray',
            'icon_size' => 'normal',
            'tip_style' => array(
                'color' => 'light',
            ),
            'tip_position' => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect' => array(
                'show' => array(
                    'duration' => '500',
                    'event' => 'mouseover',
                ),
                'hide' => array(
                    'duration' => '500',
                    'event' => 'mouseleave unfocus',
                ),
            ),
        ),
        'output' => TRUE,
        'output_tag' => TRUE,
        'settings_api' => TRUE,
        'cdn_check_time' => '1440',
        'compiler' => TRUE,
        'page_permissions' => 'manage_options',
        'save_defaults' => TRUE,
        'show_import_export' => TRUE,
        'database' => 'options',
        'transient_time' => '3600',
        'network_sites' => TRUE,
    );    

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */

    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => esc_html__( 'Theme Information 1', 'continal' ),
            'content' => esc_html__( '<p>This is the tab content, HTML is allowed.</p>', 'continal' )
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => esc_html__( 'Theme Information 2', 'continal' ),
            'content' => esc_html__( '<p>This is the tab content, HTML is allowed.</p>', 'continal' )
        )
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content = esc_html__( '<p>This is the sidebar content, HTML is allowed.</p>', 'continal' );
    Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    // ACTUAL DECLARATION OF SECTIONS          
    Redux::setSection( $opt_name, array(
        'icon' => ' el-icon-stackoverflow',
        'title' => esc_html__('Miscellaneous Settings', 'continal'),
        'fields' => array(
            array(
                'id'       => 'preload-switch',
                'type'     => 'switch', 
                'title'    => esc_html__('Preload', 'continal'),
                'subtitle' => esc_html__('Look, it\'s on!', 'continal'),
                'default'  => true,
            ),                                                
        )
    ) );

    Redux::setSection( $opt_name, array(
        'icon' => ' el-icon-picture',
        'title' => esc_html__('Logo & Favicon Settings', 'continal'),
        'fields' => array(
            array(
                'id' => 'favicon',
                'type' => 'media',
                'url' => true,
                'title' => esc_html__('Favicon', 'continal'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => esc_html__('Favicon.', 'continal'),
                'subtitle' => esc_html__('Favicon', 'continal'),
               'default' => array('url' => get_template_directory_uri().'/images/favicon.ico'),                     
            ),
            array(
                'id' => 'logo',
                'type' => 'media',
                'url' => true,
                'title' => esc_html__('Logo Static', 'continal'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => esc_html__('logo.', 'continal'),
                'subtitle' => esc_html__('Logo', 'continal'),
               'default' => array('url' => get_template_directory_uri().'/images/logo.png'),                     
            ),                                           
        )
    ) );    
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-qrcode',
        'title' => esc_html__('Header Settings', 'continal'),
        'fields' => array(
            array(
                'id' => 'header_layout',
                'type' => 'select',
                'title' => esc_html__('Header layout', 'continal'),
                'subtitle' => esc_html__('Header layout', 'continal'),
                'desc' => esc_html__('Header layout : select header layout', 'continal'),
                'options'  => array(
                    'header1' => 'Header Layout 1',
                    'header2' => 'Header Layout 2', 
                    'header3' => 'Header Layout 3',
                    'header4' => 'Header Layout 4',
                    'header5' => 'Header Layout 5',
                    'header6' => 'Header Layout 6',
                ),
                'default' => 'header1',
            ),
            array(
                'id'       => 'search-switch',
                'type'     => 'switch', 
                'title'    => esc_html__('Search In Header', 'continal'),
                'subtitle' => esc_html__('Look, it\'s on! Use for Header Layout 5', 'continal'),
                'default'  => true,
            ),
            array(
                'id' => 'header-background-color',
                'type' => 'color',
                'title' => esc_html__('Header Static Background Color', 'continal'),
                'subtitle' => esc_html__('Pick the header static background color for the theme (default: #fff).', 'continal'),
                'default' => '#fff',
                'validate' => 'color',
            ),                    
            array(
                'id' => 'header-small-background-color',
                'type' => 'color',
                'title' => esc_html__('Header Scroll Background Color', 'continal'),
                'subtitle' => esc_html__('Pick the header scroll background color for the theme (default: ##fff) with opacity : 0.9.', 'continal'),
                'default' => '#fff',
                'validate' => 'color',
            ),                             
            array(
                'id' => 'header-text-menu-color',
                'type' => 'color',
                'title' => esc_html__('Header Text Menu Color', 'continal'),
                'subtitle' => esc_html__('Pick the header text color for the theme (default: #666).', 'continal'),
                'default' => '#666',
                'validate' => 'color',
            ),
            array(
                'id' => 'header-text-info-color',
                'type' => 'color',
                'title' => esc_html__('Header Text Info Color', 'continal'),
                'subtitle' => esc_html__('Pick the header text color for the theme (default: #888).', 'continal'),
                'default' => '#888',
                'validate' => 'color',
            ),
            array(
                'id' => 'header_text',
                'type' => 'editor',
                'title' => esc_html__('Header Text', 'continal'),
                'subtitle' => esc_html__('Information Text', 'continal'),
                'default' => '',
            ),                                              
        )
    ) );
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-font',
        'title' => esc_html__('Typography', 'continal'),
        'fields' => array(
            array(
                'id' => 'h1-typography',
                'type' => 'typography',
                'output' => array('h1'),
                'title' => esc_html__('Heading 1', 'continal'),
                'subtitle' => esc_html__('Specify the heading 1 font properties.', 'continal'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => ''
                ),
            ),   
            array(
                'id' => 'h2-typography',
                'type' => 'typography',
                'output' => array('h2'),
                'title' => esc_html__('Heading 2', 'continal'),
                'subtitle' => esc_html__('Specify the heading 2 font properties.', 'continal'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => ''
                ),
            ), 
            array(
                'id' => 'h3-typography',
                'type' => 'typography',
                'output' => array('h3'),
                'title' => esc_html__('Heading 3', 'continal'),
                'subtitle' => esc_html__('Specify the heading 3 font properties.', 'continal'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => ''
                ),
            ), 
            array(
                'id' => 'h4-typography',
                'type' => 'typography',
                'output' => array('h4'),
                'title' => esc_html__('Heading 4', 'continal'),
                'subtitle' => esc_html__('Specify the heading 4 font properties.', 'continal'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => ''
                ),
            ), 
            array(
                'id' => 'h5-typography',
                'type' => 'typography',
                'output' => array('h5'),
                'title' => esc_html__('Heading 5', 'continal'),
                'subtitle' => esc_html__('Specify the heading 5 font properties.', 'continal'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => ''
                ),
            ), 
            array(
                'id' => 'h6-typography',
                'type' => 'typography',
                'output' => array('h6'),
                'title' => esc_html__('Heading 6', 'continal'),
                'subtitle' => esc_html__('Specify the heading 6 font properties.', 'continal'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => ''
                ),
            ),    

            array(
                'id' => 'menu-typography',
                'type' => 'typography',
                'output' => array('#mainmenu a'),
                'title' => esc_html__('Menu item', 'continal'),
                'subtitle' => esc_html__('Specify the Menu item font properties.', 'continal'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => '',
                ),
            ),                                   
        )
    ) );

    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-blogger',
        'title' => esc_html__('Blog Settings', 'continal'),
        'fields' => array(
            array(
                'id' => 'blog_excerpt',
                'type' => 'text',
                'title' => esc_html__('Blog custom excerpt lenght', 'continal'),
                'subtitle' => esc_html__('Input Blog custom excerpt lenght', 'continal'),
                'desc' => esc_html__('Blog custom excerpt lenght', 'continal'),
                'default' => '30'
            ),
            array(
                'id' => 'the_blog_title',
                'type' => 'text',
                'title' => esc_html__('The Blog Title', 'continal'),
                'subtitle' => esc_html__('Input blog title', 'continal'),
                'desc' => esc_html__('The Blog Title', 'continal'),
                'default' => 'COMPANY NEWS'
            ),
            array(
                'id' => 'blog_layout',
                'type' => 'select',
                'title' => esc_html__('Blog Layout', 'continal'),
                'subtitle' => esc_html__('Select', 'continal'),
                'options'  => array(
                    'style1' => 'Sidebar',
                    'style2'  => 'Fullwidth',
                ),
                'default' => 'style1',
            ),              
         )
    ) );     
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-group',
        'title' => esc_html__('Social Settings', 'continal'),
        'fields' => array(
            array(
                'id' => 'facebook',
                'type' => 'text',
                'title' => esc_html__('Facebook Url', 'continal'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => 'https://www.facebook.com/',
            ),
            array(
                'id' => 'twitter',
                'type' => 'text',
                'title' => esc_html__('Twitter Url', 'continal'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => 'https://twitter.com/',
            ),
            array(
                'id' => 'google',
                'type' => 'text',
                'title' => esc_html__('Google+ Url', 'continal'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => 'https://plus.google.com',
            ),                      
            array(
                'id' => 'github',
                'type' => 'text',
                'title' => esc_html__('Github Url', 'continal'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),
            array(
                'id' => 'youtube',
                'type' => 'text',
                'title' => esc_html__('Youtube Url', 'continal'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '',
            ),
            array(
                'id' => 'linkedin',
                'type' => 'text',
                'title' => esc_html__('Linkedin Url', 'continal'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '',
            ),
            array(
                'id' => 'dribbble',
                'type' => 'text',
                'title' => esc_html__('Dribbble Url', 'continal'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '',
            ),
            array(
                'id' => 'behance',
                'type' => 'text',
                'title' => esc_html__('Behance Url', 'continal'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),
            array(
                'id' => 'instagram',
                'type' => 'text',
                'title' => esc_html__('Instagram Url', 'continal'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),
            array(
                'id' => 'skype',
                'type' => 'text',
                'title' => esc_html__('Skype Url', 'continal'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),  
            array(
                'id' => 'pinterest',
                'type' => 'text',
                'title' => esc_html__('pinterest Url', 'continal'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ), 
            array(
                'id' => 'vimeo',
                'type' => 'text',
                'title' => esc_html__('Vimeo Url', 'continal'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),
            array(
                'id' => 'soundcloud',
                'type' => 'text',
                'title' => esc_html__('Soundcloud Url', 'continal'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ), 
            array(
                'id' => 'rss',
                'type' => 'text',
                'title' => esc_html__('RSS Url', 'continal'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '',
            ), 
        )
    ) );
    Redux::setSection( $opt_name, array(
        'icon' => ' el-icon-credit-card',
        'title' => esc_html__('Footer Settings', 'continal'),
        'fields' => array(  
            array(
                'id' => 'footer_bg',
                'type' => 'media',
                'url' => true,
                'title' => esc_html__('Footer Background Image', 'continal'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => esc_html__('Footer background image', 'continal'),
                'subtitle' => esc_html__('Footer background image', 'continal'),
               'default' => array('url' => get_template_directory_uri().'/images/bg-dark.png'),                     
            ), 
            array(
                'id' => 'footer_bg_style',
                'type' => 'select',
                'title' => esc_html__('Background Image Footer Style', 'continal'),
                'subtitle' => esc_html__('Select', 'continal'),
                'options'  => array(
                    'repeat' => 'Repeat',
                    'cover'  => 'Cover',
                ),
                'default' => 'repeat',
            ),
            array(
                'id' => 'footer_bg_color',
                'type' => 'color',
                'title' => esc_html__('Footer Background Color', 'continal'),
                'subtitle' => esc_html__("If don't use background image. Pick the color for the theme (default: transparent).", 'continal'),
                'default' => 'transparent',
                'validate' => 'color',
            ), 
            array(
                'id' => 'footer_bottom_bg_color',
                'type' => 'color',
                'title' => esc_html__('Footer Bottom Background Color', 'continal'),
                'subtitle' => esc_html__("Pick the color for the theme (default: #333).", 'continal'),
                'default' => '#333',
                'validate' => 'color',
            ),
            array(
                'id' => 'footer_text_color',
                'type' => 'color',
                'title' => esc_html__('Footer Text Color', 'continal'),
                'subtitle' => esc_html__("Pick the color for the text (default: #e5e5e5).", 'continal'),
                'default' => '#e5e5e5',
                'validate' => 'color',
            ),                   
            array(
                'id' => 'footer_text',
                'type' => 'editor',
                'title' => esc_html__('Footer Text', 'continal'),
                'subtitle' => esc_html__('Copyright Text', 'continal'),
                'default' => 'Copyright 2016 - Continal by ThemeModern',
            ),                    
        )
    ) );
    Redux::setSection( $opt_name, array(
        'icon' => ' el-icon-hourglass',
        'title' => esc_html__('Coming Soon Settings', 'continal'),
        'fields' => array(  
            array(
                'id' => 'cms_bg',
                'type' => 'media',
                'title' => esc_html__('Background Image', 'continal'),
                'subtitle' => esc_html__('Background Image', 'continal'),
                'desc' => esc_html__('Use For Coming Soon Page', 'continal'),
                'default' => array('url' => get_template_directory_uri().'/images/coming-soon.jpg')
            ), 
            array(
                'id'          => 'cms_date',
                'type'        => 'date',
                'title'       => esc_html__('Date Option', 'continal'), 
                'subtitle'    => esc_html__('No validation can be done on this field type', 'continal'),
                'desc'        => esc_html__('This is the description field, again good for additional info.', 'continal'),
                'placeholder' => 'Click to enter a date',
                'default' => '12/23/2018'
            ),  
            array(
                'id'       => 'newsletter',
                'type'     => 'switch', 
                'title'    => esc_html__('Use Newsletter', 'continal'),
                'subtitle' => esc_html__('Look, it\'s on!', 'continal'),
                'default'  => true,
            ),                   
        )
    ) );
    Redux::setSection( $opt_name, array(
        'icon' => ' el-icon-graph',
        'title' => esc_html__('404 Settings', 'continal'),
        'fields' => array( 
            array(
                'id' => '404_img',
                'type' => 'media',
                'url' => true,
                'title' => esc_html__('404 Image', 'continal'),
                'compiler' => 'true',
                'default' => array('url' => get_template_directory_uri().'/images/404.png'),                     
            ),                  
        )
    ) );
    
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-website',
        'title' => esc_html__('Styling Options', 'continal'),
        'fields' => array( 
            array(
                'id' => 'theme_style',
                'type' => 'select',
                'title' => esc_html__('Theme Style', 'continal'),
                'subtitle' => esc_html__('Select Theme Style', 'continal'),
                'options'  => array(
                    'wide' => 'Theme Version Wide',
                    'boxed'  => 'Theme Version Boxed',
                ),
                'default' => 'wide',
            ),   
            array(
                'id' => 'bg_allpage',
                'type' => 'media',
                'url' => true,
                'title' => esc_html__('Background Header All Pages', 'continal'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => esc_html__('Background Header All Pages', 'continal'),
                'subtitle' => esc_html__('Background Header All Pages', 'continal'),
               'default' => array('url' => get_template_directory_uri().'/images/bg-title.png'),                     
            ), 
            array(
                'id' => 'bg_allpage_style',
                'type' => 'select',
                'title' => esc_html__('Background Header Style', 'continal'),
                'subtitle' => esc_html__('Select', 'continal'),
                'options'  => array(
                    'repeat' => 'Repeat',
                    'cover'  => 'Cover',
                ),
                'default' => 'repeat',
            ),                    
            array(
                'id' => 'main-color',
                'type' => 'color',
                'title' => esc_html__('Theme Main Color', 'continal'),
                'subtitle' => esc_html__('Pick the main color for the theme (default: #ffae4e).', 'continal'),
                'default' => '#ffae4e',
                'validate' => 'color',
            ),  
            array(
                'id' => 'footer_textcolor',
                'type' => 'color',
                'title' => esc_html__('Footer Text Color', 'continal'),
                'subtitle' => esc_html__('Pick the Footer Text color for the theme (default: #cccccc).', 'continal'),
                'default' => '#cccccc',
                'validate' => 'color',
            ),
            array(
                'id' => 'footer_bgcolor',
                'type' => 'color',
                'title' => esc_html__('Footer Background Color', 'continal'),
                'subtitle' => esc_html__('Pick the Footer Background color for the theme (default: #101314).', 'continal'),
                'default' => '#101314',
                'validate' => 'color',
            ),
            array(
                'id' => 'footer_bottom_bgcolor',
                'type' => 'color',
                'title' => esc_html__('Footer Bottom Background Color', 'continal'),
                'subtitle' => esc_html__('Pick the Footer Bottom Background color for the theme.', 'continal'),
                'default' => '',
                'validate' => 'color',
            ),
            array(
                'id' => 'body-font2',
                'type' => 'typography',
                'output' => array('body'),
                'title' => esc_html__('Body Font', 'continal'),
                'subtitle' => esc_html__('Specify the body font properties.', 'continal'),
                'google' => true,
                'default' => array(
                    'color' => '',
                    'font-size' => '',
                    'line-height' => '',
                    'font-family' => '',
                    'font-weight' => ''
                ),
            ),
             array(
                'id' => 'custom-css',
                'type' => 'ace_editor',
                'title' => esc_html__('CSS Code', 'continal'),
                'subtitle' => esc_html__('Paste your CSS code here.', 'continal'),
                'mode' => 'css',
                'theme' => 'monokai',
                'desc' => 'Possible modes can be found at http://ace.c9.io/.',
                'default' => "#header{\nmargin: 0 auto;\n}"
            ),
        )
    ) );

    /*
     * <--- END SECTIONS
     */
