<?php
/**
 * Redux Theme functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package continal
 */

if ( ! class_exists( 'ReduxFramewrk' ) ) {
    require_once( get_template_directory() . '/framework/sample-config.php' );
	function removeDemoModeLink() { // Be sure to rename this function to something more unique
		if ( class_exists('ReduxFrameworkPlugin') ) {
			remove_filter( 'plugin_row_meta', array( ReduxFrameworkPlugin::get_instance(), 'plugin_metalinks'), null, 2 );
		}
		if ( class_exists('ReduxFrameworkPlugin') ) {
			remove_action('admin_notices', array( ReduxFrameworkPlugin::get_instance(), 'admin_notices' ) );    
		}
	}
	add_action('init', 'removeDemoModeLink');
}

if ( ! function_exists( 'continal_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function continal_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Redux Theme, use a find and replace
	 * to change 'continal' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'continal', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'custom-header' );
	add_theme_support( 'custom-background' ); 

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'continal' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-list',
		'comment-form',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'audio',
		'image',
		'video',
		'gallery',
	) );
	
}
endif; // continal_setup
add_action( 'after_setup_theme', 'continal_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function continal_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'continal_content_width', 640 );
}
add_action( 'after_setup_theme', 'continal_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function continal_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'continal' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Appears in the sidebar section of the site.', 'continal' ),  
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar Shop', 'continal' ),
		'id'            => 'sidebar-shop',
		'description'   => esc_html__( 'Appears in the sidebar section of the site.', 'continal' ),  
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer One Widget Area', 'continal' ),
		'id'            => 'footer-area-1',
		'description'   => esc_html__( 'Footer Widget that appears on the Footer.', 'continal' ),
		'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4>',
		'after_title'   => '</h4><div class="tiny-border"></div>',
	) );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Two Widget Area', 'continal' ),
		'id'            => 'footer-area-2',
		'description'   => esc_html__( 'Footer Widget that appears on the Footer.', 'continal' ),
		'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4>',
		'after_title'   => '</h4><div class="tiny-border"></div>',
	) );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Three Widget Area', 'continal' ),
		'id'            => 'footer-area-3',
		'description'   => esc_html__( 'Footer Widget that appears on the Footer.', 'continal' ),
		'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4>',
		'after_title'   => '</h4><div class="tiny-border"></div>',
	) );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Fourth Widget Area', 'continal' ),
		'id'            => 'footer-area-4',
		'description'   => esc_html__( 'Footer Widget that appears on the Footer.', 'continal' ),
		'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4>',
		'after_title'   => '</h4><div class="tiny-border"></div>',
	) ); 

	
}
add_action( 'widgets_init', 'continal_widgets_init' );

/**
 * Enqueue Google fonts.
 */
function continal_fonts_url() {
    $fonts_url = '';

    /* Translators: If there are characters in your language that are not
    * supported by Lora, translate this to 'off'. Do not translate
    * into your own language.
    */
    $open_sans = _x( 'on', 'Open Sans font: on or off', 'continal' );
 
    /* Translators: If there are characters in your language that are not
    * supported by Lora, translate this to 'off'. Do not translate
    * into your own language.
    */
    
    if ( 'off' !== $open_sans ) {
        $font_families = array();

        if ( 'off' !== $open_sans ) {
            $font_families[] = 'Open Sans:400,300,300italic,400italic,700,700italic,900,900italic';
        }      
 
        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
        );
 
        $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
    }
 
    return esc_url_raw( $fonts_url );
}

/**
 * Enqueue scripts and styles.
 */
function continal_scripts() {
	global $continal_option;
	$protocol = is_ssl() ? 'https' : 'http';

	// Add custom fonts, used in the main stylesheet.
    wp_enqueue_style( 'continal-fonts', continal_fonts_url(), array(), null );

    /** All frontend css files **/ 
    wp_enqueue_style( 'bootstrap', get_template_directory_uri().'/css/bootstrap.min.css');
    wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/css/font-awesome.min.css');
	wp_enqueue_style( 'owl-carousel', get_template_directory_uri().'/css/owl.carousel.css'); 
 	wp_enqueue_style( 'colorbox', get_template_directory_uri().'/css/colorbox.css'); 
 	wp_enqueue_style( 'continal-woocommerce', get_template_directory_uri().'/css/woo.css');  
	wp_enqueue_style( 'continal-style', get_stylesheet_uri() );
	
	// Custom color theme.
	wp_enqueue_style( 'continal-color', get_template_directory_uri() . '/framework/color.php');	

	/** All frontend js files **/    
	wp_enqueue_script("carousel", get_template_directory_uri()."/js/owl.carousel.min.js",array('jquery'),false,true); 
    wp_enqueue_script("mapapi", "$protocol://maps.google.com/maps/api/js?key=AIzaSyAvpnlHRidMIU374bKM5-sx8ruc01OvDjI",array('jquery'),false,false);   
	wp_enqueue_script("classie", get_template_directory_uri()."/js/classie.js",array('jquery'),false,true);    
	wp_enqueue_script("fitvids", get_template_directory_uri()."/js/jquery.fitvids.js",array('jquery'),false,true);
    wp_enqueue_script("counterup", get_template_directory_uri()."/js/jquery.counterup.min.js",array('jquery'),false,true);
	wp_enqueue_script("colorbox", get_template_directory_uri()."/js/jquery.colorbox.js",array('jquery'),false,true);
    wp_enqueue_script("isotope", get_template_directory_uri()."/js/jquery.isotope.min.js",array('jquery'),false,true);
    wp_enqueue_script("easing", get_template_directory_uri()."/js/jquery.easing.js",array('jquery'),false,true);
	wp_enqueue_script("responsiveTabs", get_template_directory_uri()."/js/jquery.responsiveTabs.js",array('jquery'),false,true);
    wp_enqueue_script("visible", get_template_directory_uri()."/js/visible.min.js",array('jquery'),false,true);
	wp_enqueue_script("waypoints", get_template_directory_uri()."/js/waypoints.min.js",array('jquery'),false,true);
    wp_enqueue_script("continal-custom", get_template_directory_uri()."/js/custom.js",array('jquery'),false,true);  
}
add_action( 'wp_enqueue_scripts', 'continal_scripts' );

if(!function_exists('continal_custom_frontend_style')){
    function continal_custom_frontend_style(){
        global $continal_option;
        echo '<style type="text/css">'.$continal_option['custom-css'].'</style>';
    }
}
add_action('wp_head', 'continal_custom_frontend_style');

/**
 * Implement the Custom Meta Boxs.
 */
require get_template_directory() . '/framework/meta-boxes.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/framework/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/framework/widget/flickr.php';
require_once get_template_directory() . '/shortcodes.php';
require_once get_template_directory() . '/vc_shortcode.php';
/**
 * Customizer Menu.
 */
require get_template_directory() . '/framework/wp_bootstrap_navwalker.php';

/**
 *Hooked Woocommerce
 */
require get_template_directory() . '/framework/woocommerce.php';

//Code Visual Composer.
// Add new Param in Row
if(function_exists('vc_add_param')){
	vc_add_param(
		'vc_row',
		array(
			"type" => "dropdown",
			"heading" => esc_html__('Setup Full width For Row.', 'continal'),
			"param_name" => "fullwidth",
			"value" => array(   
			                esc_html__('No', 'continal') => 'no',  
			                esc_html__('Yes', 'continal') => 'yes',                                                                                
			              ),
			"description" => esc_html__("Select Full width for row : yes or not, Default: No fullwidth", "continal"),      
        )
    );
    vc_add_param(
		'vc_row',
		array(
			"type" => "dropdown",
			"heading" => esc_html__('Setup Parallax Background For Row.', 'continal'),
			"param_name" => "parallax_row",
			"value" => array(   
			                esc_html__('No', 'continal') => 'no',  
			                esc_html__('Yes', 'continal') => 'yes',                                                                                
			              ),
			"description" => esc_html__("Select parallax background for row : yes or not, Default: No parallax", "continal"),      
        )
    );
    vc_add_param(
		'vc_row',
		array(
			"type" => "checkbox",
			"heading" => esc_html__('Use Overlay For Background Image', 'continal'),
			"param_name" => "overlay",
			"value" => '',
			"description" => esc_html__("Overlay background: rgba(12, 20, 32, 0.7). ", "continal"),  
			    
        )
    );	  
}

if(function_exists('vc_remove_param')){
	vc_remove_param( "vc_row", "parallax" );
	vc_remove_param( "vc_row", "parallax_image" );
	vc_remove_param( "vc_row", "full_width" );
	vc_remove_param( "vc_row", "full_height" );
	vc_remove_param( "vc_row", "video_bg" );
	vc_remove_param( "vc_row", "video_bg_parallax" );
	vc_remove_param( "vc_row", "content_placement" );
	vc_remove_param( "vc_row", "video_bg_url" );
	vc_remove_param( "vc_row", "columns_placement" );
	vc_remove_param( "vc_row", "gap" );
	vc_remove_param( "vc_row", "equal_height" );
	vc_remove_param( "vc_row", "disable_element" );
	vc_remove_param( "vc_row", "parallax_speed_video" );
	vc_remove_param( "vc_row", "parallax_speed_bg" );
	vc_remove_element( "vc_basic_grid" );
	vc_remove_element( "vc_masonry_grid" );
	vc_remove_element( "vc_media_grid" );
	vc_remove_element( "vc_masonry_media_grid" );
}	

/**
 * Require plugins install for this theme.
 *
 * @since Split Vcard 1.0
 */
require_once get_template_directory() . '/framework/plugin-requires.php';